"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import dbtlabs.proto.public.v1.events.vortex_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _OnboardingScreen:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OnboardingScreenEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OnboardingScreen.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SCREEN_UNSPECIFIED: _OnboardingScreen.ValueType  # 0
    WELCOME: _OnboardingScreen.ValueType  # 1
    PROFILE_CHECK: _OnboardingScreen.ValueType  # 2
    PROFILE_FOUND: _OnboardingScreen.ValueType  # 3
    PROFILE_SETUP: _OnboardingScreen.ValueType  # 4
    LINK_ACCOUNT: _OnboardingScreen.ValueType  # 5
    DBT_PARSE: _OnboardingScreen.ValueType  # 6
    PARSE_ERROR_AUTOFIX: _OnboardingScreen.ValueType  # 7
    DBT_PARSE_RETRY: _OnboardingScreen.ValueType  # 8
    PARSE_ERROR_FAIL: _OnboardingScreen.ValueType  # 9
    COMPILE_NO_SA: _OnboardingScreen.ValueType  # 10
    COMPILE_NO_SA_FAIL: _OnboardingScreen.ValueType  # 11
    COMPILE: _OnboardingScreen.ValueType  # 12
    COMPILE_FAIL: _OnboardingScreen.ValueType  # 13
    SUCCESS: _OnboardingScreen.ValueType  # 14
    AGENTIC_AUTOFIX: _OnboardingScreen.ValueType  # 15
    TRY_AGENTIC_AUTOFIX: _OnboardingScreen.ValueType  # 16
    DOWNLOAD_AGENTS_MD: _OnboardingScreen.ValueType  # 17

class OnboardingScreen(_OnboardingScreen, metaclass=_OnboardingScreenEnumTypeWrapper): ...

SCREEN_UNSPECIFIED: OnboardingScreen.ValueType  # 0
WELCOME: OnboardingScreen.ValueType  # 1
PROFILE_CHECK: OnboardingScreen.ValueType  # 2
PROFILE_FOUND: OnboardingScreen.ValueType  # 3
PROFILE_SETUP: OnboardingScreen.ValueType  # 4
LINK_ACCOUNT: OnboardingScreen.ValueType  # 5
DBT_PARSE: OnboardingScreen.ValueType  # 6
PARSE_ERROR_AUTOFIX: OnboardingScreen.ValueType  # 7
DBT_PARSE_RETRY: OnboardingScreen.ValueType  # 8
PARSE_ERROR_FAIL: OnboardingScreen.ValueType  # 9
COMPILE_NO_SA: OnboardingScreen.ValueType  # 10
COMPILE_NO_SA_FAIL: OnboardingScreen.ValueType  # 11
COMPILE: OnboardingScreen.ValueType  # 12
COMPILE_FAIL: OnboardingScreen.ValueType  # 13
SUCCESS: OnboardingScreen.ValueType  # 14
AGENTIC_AUTOFIX: OnboardingScreen.ValueType  # 15
TRY_AGENTIC_AUTOFIX: OnboardingScreen.ValueType  # 16
DOWNLOAD_AGENTS_MD: OnboardingScreen.ValueType  # 17
Global___OnboardingScreen: typing_extensions.TypeAlias = OnboardingScreen

class _OnboardingAction:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _OnboardingActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_OnboardingAction.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ACTION_UNSPECIFIED: _OnboardingAction.ValueType  # 0
    INITIATED: _OnboardingAction.ValueType  # 1
    """flow start (WELCOME)"""
    SCREEN_SHOWN: _OnboardingAction.ValueType  # 2
    """screen displayed"""
    RUN_STARTED: _OnboardingAction.ValueType  # 3
    """parse/compile began"""
    RUN_FINISHED: _OnboardingAction.ValueType  # 4
    """parse/compile ended (use success)"""
    STEP_COMPLETED: _OnboardingAction.ValueType  # 5
    """checkpoint reached (use success)"""
    STEP_FAILED: _OnboardingAction.ValueType  # 6
    """explicit failure"""

class OnboardingAction(_OnboardingAction, metaclass=_OnboardingActionEnumTypeWrapper): ...

ACTION_UNSPECIFIED: OnboardingAction.ValueType  # 0
INITIATED: OnboardingAction.ValueType  # 1
"""flow start (WELCOME)"""
SCREEN_SHOWN: OnboardingAction.ValueType  # 2
"""screen displayed"""
RUN_STARTED: OnboardingAction.ValueType  # 3
"""parse/compile began"""
RUN_FINISHED: OnboardingAction.ValueType  # 4
"""parse/compile ended (use success)"""
STEP_COMPLETED: OnboardingAction.ValueType  # 5
"""checkpoint reached (use success)"""
STEP_FAILED: OnboardingAction.ValueType  # 6
"""explicit failure"""
Global___OnboardingAction: typing_extensions.TypeAlias = OnboardingAction

@typing.final
class AdapterInfo(google.protobuf.message.Message):
    """
    RFC 2119 Expectations for using these events:

    1. When the Fusion process starts it MUST emit the `Invocation` event once at the start of the process before any other events
    a. The `invocation_id` field MUST be set to a globally unique ID
    b. All fields that have a `Required` comment MUST be set
    c. All other fields without a `Required` comment MAY be set and are optional if they can be found
    2. After the Fusion emits the `Invocation` event it MAY emit the `v1.events.fusion.CloudInvocation` at the start of the process before any other events
    3. Fusion MUST emit a `RunModel` event for every model in the project that is part of the Node Selector
    a. Fusion MAY omit `RunModel` events for nodes that are not part of the Node Selector used https://docs.getdbt.com/reference/node-selection/syntax

    Adapter Info Event is responsible for foundational adapter information.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    ADAPTER_TYPE_FIELD_NUMBER: builtins.int
    ADAPTER_UNIQUE_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    invocation_id: builtins.str
    """A foreign key to the Invocation message that was emitted at the
    start of the fusion process.
    Required.
    """
    adapter_type: builtins.str
    """adapter_type is the plain string name for the dbt adapter that's used by the
    project. Examples could include: "bigquery", "snowflake", "redshift", "postgres", etc.
    """
    adapter_unique_id: builtins.str
    """adapter_unique_id is the unique identifier of a project's warehouse credentials.
    For supported warehouses, we create an MD5 hash of the connection string.
    The specific string varies per adapter_type.
    """
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        adapter_type: builtins.str = ...,
        adapter_unique_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_type", b"adapter_type", "adapter_unique_id", b"adapter_unique_id", "enrichment", b"enrichment", "event_id", b"event_id", "invocation_id", b"invocation_id"]) -> None: ...

Global___AdapterInfo: typing_extensions.TypeAlias = AdapterInfo

@typing.final
class AdapterInfoV2(google.protobuf.message.Message):
    """Adapter Info V2 Event was created when we needed to collect more information
    about the adapter. Unlike AdapterInfo above, this event is tied to RunModel
    events. Here we're able to collect adapter-specific information at the
    individual model level. This was first created when we started to collect
    information on which models were Iceberg-powered.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ModelAdapterDetailsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    RUN_MODEL_ID_FIELD_NUMBER: builtins.int
    ADAPTER_NAME_FIELD_NUMBER: builtins.int
    BASE_ADAPTER_VERSION_FIELD_NUMBER: builtins.int
    ADAPTER_VERSION_FIELD_NUMBER: builtins.int
    MODEL_ADAPTER_DETAILS_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    run_model_id: builtins.str
    """A foreign key to the RunModel message that was emitted at each instance
    of an individual model being run.
    """
    adapter_name: builtins.str
    """This reflects the adapter name used when they ran a given model."""
    base_adapter_version: builtins.str
    """This reflects the simplified semantic version of an adapter that was used
    when they ran a given model. ex. 1.9.0
    """
    adapter_version: builtins.str
    """This reflects the full adapter version used when they ran a given model."""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    @property
    def model_adapter_details(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """This is a flexible key-value pair that can be used to store any additional
        model adapter information. Today this is used to store two pieces of
        information: the model_adapter_type (the adapter_name that was used for
        that specific model) and the model_adapter_table_format (Iceberg or
        something else).
        """

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        run_model_id: builtins.str = ...,
        adapter_name: builtins.str = ...,
        base_adapter_version: builtins.str = ...,
        adapter_version: builtins.str = ...,
        model_adapter_details: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["adapter_name", b"adapter_name", "adapter_version", b"adapter_version", "base_adapter_version", b"base_adapter_version", "enrichment", b"enrichment", "event_id", b"event_id", "model_adapter_details", b"model_adapter_details", "run_model_id", b"run_model_id"]) -> None: ...

Global___AdapterInfoV2: typing_extensions.TypeAlias = AdapterInfoV2

@typing.final
class Invocation(google.protobuf.message.Message):
    """Invocation Event is emitted by dbt when a user runs a command and begins to
    emit basic environment information out that can be referred to later on by
    other events that are emitted. This event then fires off a second time when
    the invocation has completed. Upon completion, we get more information about
    the end state of this action.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    PROJECT_ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    RESULT_TYPE_FIELD_NUMBER: builtins.int
    GIT_COMMIT_SHA_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID.
    Required.
    """
    invocation_id: builtins.str
    """This is the globally unique identifier for this invocation event.
    It is emitted once during the lifetime of the fusion process at the
    beginning and referred to by other messages using this ID.
    Required.
    """
    project_id: builtins.str
    """project_id is the MD5 hash of the project name that's supplied in the
    dbt_project.yml file. This is originally the primary identifier for our anonymous
    usage tracking. Today we couple this with the AdapterInfo adapter_unique_id.
    """
    user_id: builtins.str
    """user_id is the UUID generated to identify a unique user. We store a cookie
    or token in the user's local directory which we use to maintain user information
    across sessions. This is usually found in ~/.dbt/.user.yml.
    """
    command: builtins.str
    """The full string of the command that was run."""
    progress: builtins.str
    """A string that indicates whether the event represents the start or end of an
    invocation. The valid values for this are:

     start
     end
     invalid
     ok
    """
    version: builtins.str
    """The version of dbt that was used to run this command."""
    result_type: builtins.str
    """The exit state of an invocation's start or end event. The valid values for this are:

     started
     ok
     invalid_profile
     error
    """
    git_commit_sha: builtins.str
    """The SHA of the git commit of the dbt project being run if it is found.
    If there are changes that aren't committed we may also want to have a
    git_commit_dirty boolean to indicate there are some staged or unstaged
    changes.  In the RunModel message there is also a hashed_contents which
    gives a hash of the model being run which may be finer granularity than
    at a project level.
    """
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        project_id: builtins.str = ...,
        user_id: builtins.str = ...,
        command: builtins.str = ...,
        progress: builtins.str = ...,
        version: builtins.str = ...,
        result_type: builtins.str = ...,
        git_commit_sha: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["command", b"command", "enrichment", b"enrichment", "event_id", b"event_id", "git_commit_sha", b"git_commit_sha", "invocation_id", b"invocation_id", "progress", b"progress", "project_id", b"project_id", "result_type", b"result_type", "user_id", b"user_id", "version", b"version"]) -> None: ...

Global___Invocation: typing_extensions.TypeAlias = Invocation

@typing.final
class InvocationEnv(google.protobuf.message.Message):
    """Invocation Environment Event is the primary way we are able to associate
    invocation telemetry data with our dbt Cloud information. Values are supplied
    here whenever dbt is run in a cloud environment.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    invocation_id: builtins.str
    """A foreign key to the Invocation message that was emitted at the
    start of the fusion process.
    """
    environment: builtins.str
    """This is a string that indicates the environment in which the invocation is
    running. Our primary use case here is to pass along dbt Cloud context with
    the invocation event so we can associate the invocation with a specific
    dbt Cloud activity and account. Different cloud services have used different
    string formats and IDs provided.
    """
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        environment: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enrichment", b"enrichment", "environment", b"environment", "event_id", b"event_id", "invocation_id", b"invocation_id"]) -> None: ...

Global___InvocationEnv: typing_extensions.TypeAlias = InvocationEnv

@typing.final
class PackageInstall(google.protobuf.message.Message):
    """Package Install Event is emitted when dbt deps (or other commands that
    trigger packages to be installed) is run.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    invocation_id: builtins.str
    """A foreign key to the Invocation message that was emitted at the
    start of the fusion process.
    """
    name: builtins.str
    """plain string name of a pakage that was installed. This is often the same
    or similar to the git repository name of that package.
    """
    source: builtins.str
    """plain string source of the package. This is also referred to as the
    installation method in our internal analytics. This is based on the syntax
    used in packages.yml file.
    """
    version: builtins.str
    """either a semantic version of the package (if installed through the hub) or
    a git commit hash (if installed through git).
    """
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        name: builtins.str = ...,
        source: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["enrichment", b"enrichment", "event_id", b"event_id", "invocation_id", b"invocation_id", "name", b"name", "source", b"source", "version", b"version"]) -> None: ...

Global___PackageInstall: typing_extensions.TypeAlias = PackageInstall

@typing.final
class ResourceCounts(google.protobuf.message.Message):
    """Resource Counts Events fire after an invocation event to give a count of all
    the resources that were used in the invocation. Note that this includes all
    the resources in the active project, including those from installed packages
    and (in the case of macros) from the global dbt project. This will show all
    resources available, regardless of if they are run or not.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    MODELS_FIELD_NUMBER: builtins.int
    TESTS_FIELD_NUMBER: builtins.int
    SNAPSHOTS_FIELD_NUMBER: builtins.int
    ANALYSES_FIELD_NUMBER: builtins.int
    MACROS_FIELD_NUMBER: builtins.int
    OPERATIONS_FIELD_NUMBER: builtins.int
    SEEDS_FIELD_NUMBER: builtins.int
    SOURCES_FIELD_NUMBER: builtins.int
    EXPOSURES_FIELD_NUMBER: builtins.int
    METRICS_FIELD_NUMBER: builtins.int
    GROUPS_FIELD_NUMBER: builtins.int
    UNIT_TESTS_FIELD_NUMBER: builtins.int
    SEMANTIC_MODELS_FIELD_NUMBER: builtins.int
    SAVED_QUERIES_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    invocation_id: builtins.str
    """A foreign key to the Invocation message that was emitted at the
    start of the fusion process.
    """
    models: builtins.int
    """total count of models in the project."""
    tests: builtins.int
    """total count of data tests (originally just tests) in the project."""
    snapshots: builtins.int
    """total count of snapshots in the project."""
    analyses: builtins.int
    """total count of analysis queries in the project."""
    macros: builtins.int
    """total count of macros in the project."""
    operations: builtins.int
    """total count of operations in the project."""
    seeds: builtins.int
    """total count of seeds in the project."""
    sources: builtins.int
    """total count of sources in the project."""
    exposures: builtins.int
    """total count of exposures in the project."""
    metrics: builtins.int
    """total count of metrics in the project."""
    groups: builtins.int
    """total count of groups in the project."""
    unit_tests: builtins.int
    """total count of unit tests in the project."""
    semantic_models: builtins.int
    """total count of semantic models in the project."""
    saved_queries: builtins.int
    """total count of saved queries in the project."""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        models: builtins.int = ...,
        tests: builtins.int = ...,
        snapshots: builtins.int = ...,
        analyses: builtins.int = ...,
        macros: builtins.int = ...,
        operations: builtins.int = ...,
        seeds: builtins.int = ...,
        sources: builtins.int = ...,
        exposures: builtins.int = ...,
        metrics: builtins.int = ...,
        groups: builtins.int = ...,
        unit_tests: builtins.int = ...,
        semantic_models: builtins.int = ...,
        saved_queries: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyses", b"analyses", "enrichment", b"enrichment", "event_id", b"event_id", "exposures", b"exposures", "groups", b"groups", "invocation_id", b"invocation_id", "macros", b"macros", "metrics", b"metrics", "models", b"models", "operations", b"operations", "saved_queries", b"saved_queries", "seeds", b"seeds", "semantic_models", b"semantic_models", "snapshots", b"snapshots", "sources", b"sources", "tests", b"tests", "unit_tests", b"unit_tests"]) -> None: ...

Global___ResourceCounts: typing_extensions.TypeAlias = ResourceCounts

@typing.final
class RunModel(google.protobuf.message.Message):
    """Run Model Event will be emitted when Fusion runs a model or skips a model because
    it determines it does not need to be run. The Account Identifier and Project Identifier
    can be found by joining this message on the Invocation message specified in the invocation_id
    field.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    INDEX_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    EXECUTION_TIME_FIELD_NUMBER: builtins.int
    RUN_STATUS_FIELD_NUMBER: builtins.int
    RUN_SKIPPED_FIELD_NUMBER: builtins.int
    MODEL_MATERIALIZATION_FIELD_NUMBER: builtins.int
    MODEL_INCREMENTAL_STRATEGY_FIELD_NUMBER: builtins.int
    MODEL_ID_FIELD_NUMBER: builtins.int
    HASHED_CONTENTS_FIELD_NUMBER: builtins.int
    LANGUAGE_FIELD_NUMBER: builtins.int
    HAS_GROUP_FIELD_NUMBER: builtins.int
    CONTRACT_ENFORCED_FIELD_NUMBER: builtins.int
    ACCESS_FIELD_NUMBER: builtins.int
    VERSIONED_FIELD_NUMBER: builtins.int
    RUN_SKIPPED_REASON_FIELD_NUMBER: builtins.int
    RUN_MODEL_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """event_id is the unique identifier for this event. It is a generated UUID."""
    invocation_id: builtins.str
    """A foreign key to the Invocation message that was emitted at the
    start of the fusion process.
    """
    index: builtins.int
    """the numerical index of that model with respect to the total models being run"""
    total: builtins.int
    """the total number of models being run in this invocation"""
    execution_time: builtins.float
    """the time it took for a model to execute in seconds. This should mirror what
    is displayed in the dbt output logs next to each model.
    """
    run_status: builtins.str
    """success or failure status of that model's run. This mirrors what is displayed
    in the dbt output logs next to each model. Ex. "SUCCESS 1", "INSERT 1", "INSERT 23", etc.
    """
    run_skipped: builtins.bool
    """whether or not the model was skipped. If the run was skipped the reason it was
    skipped is indicated by the value of the run_skipped_reason field.
    """
    model_materialization: builtins.str
    """the materialization strategy used for that model"""
    model_incremental_strategy: builtins.str
    """the incremental strategy used for that model (ex. append, merge, etc.)"""
    model_id: builtins.str
    """unique identifier for the model (I believe an MD5 hash of the model name)"""
    hashed_contents: builtins.str
    """MD5 hash of the model's contents. This is used to determine if the model
    has changed since the last time it was run.
    """
    language: builtins.str
    """the language used to write the model (ex. sql, python)"""
    has_group: builtins.bool
    """whether or not the model is in a group"""
    contract_enforced: builtins.bool
    """whether or not the model is contract enforced"""
    access: builtins.str
    """the access level of the model (ex. public, private, etc.)"""
    versioned: builtins.bool
    """whether or not the model is versioned"""
    run_skipped_reason: builtins.str
    """A reason for why the model was skipped. The valid values for this are:

     cost_avoidance
     upstream_failed
    """
    run_model_id: builtins.str
    """A globally unique ID that is emitted at each instance of an individual
    model being run.
    """
    resource_type: builtins.str
    """The resource type of the node (model, test, etc.)"""
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        index: builtins.int = ...,
        total: builtins.int = ...,
        execution_time: builtins.float = ...,
        run_status: builtins.str = ...,
        run_skipped: builtins.bool = ...,
        model_materialization: builtins.str = ...,
        model_incremental_strategy: builtins.str = ...,
        model_id: builtins.str = ...,
        hashed_contents: builtins.str = ...,
        language: builtins.str = ...,
        has_group: builtins.bool = ...,
        contract_enforced: builtins.bool = ...,
        access: builtins.str = ...,
        versioned: builtins.bool = ...,
        run_skipped_reason: builtins.str = ...,
        run_model_id: builtins.str = ...,
        resource_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access", b"access", "contract_enforced", b"contract_enforced", "enrichment", b"enrichment", "event_id", b"event_id", "execution_time", b"execution_time", "has_group", b"has_group", "hashed_contents", b"hashed_contents", "index", b"index", "invocation_id", b"invocation_id", "language", b"language", "model_id", b"model_id", "model_incremental_strategy", b"model_incremental_strategy", "model_materialization", b"model_materialization", "resource_type", b"resource_type", "run_model_id", b"run_model_id", "run_skipped", b"run_skipped", "run_skipped_reason", b"run_skipped_reason", "run_status", b"run_status", "total", b"total", "versioned", b"versioned"]) -> None: ...

Global___RunModel: typing_extensions.TypeAlias = RunModel

@typing.final
class Onboarding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENRICHMENT_FIELD_NUMBER: builtins.int
    EVENT_ID_FIELD_NUMBER: builtins.int
    INVOCATION_ID_FIELD_NUMBER: builtins.int
    SCREEN_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    SUCCESS_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    event_id: builtins.str
    """Unique identifier for this event (UUID).
    Required.
    """
    invocation_id: builtins.str
    """Globally unique identifier for the fusion invocation.
    Required.
    """
    screen: Global___OnboardingScreen.ValueType
    """Onboarding semantics.
    Which screen/step
    """
    action: Global___OnboardingAction.ValueType
    """What happened on that screen"""
    success: builtins.bool
    """Only for RUN_FINISHED/STEP_COMPLETED; ignored otherwise"""
    user_id: builtins.str
    """user_id is the UUID generated to identify a unique user. We store a cookie
    or token in the user's local directory which we use to maintain user information
    across sessions. This is usually found in ~/.dbt/.user.yml.
    """
    @property
    def enrichment(self) -> dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment:
        """This field is a toggle to enable enrichment of the message by the Vortex service."""

    def __init__(
        self,
        *,
        enrichment: dbtlabs.proto.public.v1.events.vortex_pb2.VortexMessageEnrichment | None = ...,
        event_id: builtins.str = ...,
        invocation_id: builtins.str = ...,
        screen: Global___OnboardingScreen.ValueType = ...,
        action: Global___OnboardingAction.ValueType = ...,
        success: builtins.bool = ...,
        user_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["enrichment", b"enrichment"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "enrichment", b"enrichment", "event_id", b"event_id", "invocation_id", b"invocation_id", "screen", b"screen", "success", b"success", "user_id", b"user_id"]) -> None: ...

Global___Onboarding: typing_extensions.TypeAlias = Onboarding



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

package_name = "dbt-protos"
package_version = "v1.0.397"

setuptools.setup(
    name=package_name,
    version=package_version,
    author="dbt Labs, Inc.",
    author_email="info@dbtlabs.com",
    description="Public proto bindings for dbt",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/dbt-labs/proto-python-public",
    packages=setuptools.find_namespace_packages(),
    package_data={"": ["*.pyi", "py.typed"]},
    install_requires=["protobuf>=3.17.1"],
    license="Apache-2.0",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: Apache Software License",
    ],
    python_requires=">=3.6",
)



from dbtlabs.proto.public.v1.fields import *
from dbtlabs.proto.public.v1.events import *
from dbtlabs.proto.public.v1.records import *
import importlib
import pkgutil

def test_import():
    assert True

def test_import_public():
    assert True

def test_all_proto_modules_importable():
    """Test that ensures all modules under dbtlabs.proto can be imported without errors."""
    # List of base packages to check
    base_packages = [
        "dbtlabs.proto.public.v1.fields",
        "dbtlabs.proto.public.v1.events",
        "dbtlabs.proto.public.v1.records",
    ]

    # Try importing each base package
    for pkg_name in base_packages:
        try:
            # Import the package
            pkg = importlib.import_module(pkg_name)
            assert pkg is not None, f"Failed to import {pkg_name}"

            # Check if it's a package and walk through its submodules
            if hasattr(pkg, "__path__"):
                # Get all submodules
                for _, submodule_name, is_pkg in pkgutil.iter_modules(pkg.__path__, pkg.__name__ + "."):
                    try:
                        submodule = importlib.import_module(submodule_name)
                        assert submodule is not None, f"Failed to import {submodule_name}"
                    except ImportError as e:
                        assert False, f"Could not import submodule {submodule_name}: {str(e)}"
        except ImportError as e:
            assert False, f"Could not import {pkg_name}: {str(e)}. Is there a dependency from a public to a private proto?"



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/events/fusion/compat/otlp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7dbtlabs/proto/public/v1/events/fusion/compat/otlp.proto\x12\x1ev1.public.events.fusion.compat*\xb6\x01\n\x0eSeverityNumber\x12\x1f\n\x1bSEVERITY_NUMBER_UNSPECIFIED\x10\x00\x12\x19\n\x15SEVERITY_NUMBER_TRACE\x10\x01\x12\x19\n\x15SEVERITY_NUMBER_DEBUG\x10\x05\x12\x18\n\x14SEVERITY_NUMBER_INFO\x10\t\x12\x18\n\x14SEVERITY_NUMBER_WARN\x10\r\x12\x19\n\x15SEVERITY_NUMBER_ERROR\x10\x11\x42\x41Z?github.com/dbt-labs/proto-golang/v1/public/events/fusion/compatb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.events.fusion.compat.otlp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z?github.com/dbt-labs/proto-golang/v1/public/events/fusion/compat'
  _globals['_SEVERITYNUMBER']._serialized_start=92
  _globals['_SEVERITYNUMBER']._serialized_end=274
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _NodeType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_TYPE_UNSPECIFIED: _NodeType.ValueType  # 0
    NODE_TYPE_MODEL: _NodeType.ValueType  # 1
    NODE_TYPE_SEED: _NodeType.ValueType  # 2
    NODE_TYPE_SNAPSHOT: _NodeType.ValueType  # 11
    NODE_TYPE_SOURCE: _NodeType.ValueType  # 3
    NODE_TYPE_TEST: _NodeType.ValueType  # 4
    NODE_TYPE_UNIT_TEST: _NodeType.ValueType  # 5
    NODE_TYPE_MACRO: _NodeType.ValueType  # 6
    NODE_TYPE_DOCS_MACRO: _NodeType.ValueType  # 7
    NODE_TYPE_ANALYSIS: _NodeType.ValueType  # 8
    NODE_TYPE_OPERATION: _NodeType.ValueType  # 9
    NODE_TYPE_EXPOSURE: _NodeType.ValueType  # 10
    NODE_TYPE_METRIC: _NodeType.ValueType  # 12
    NODE_TYPE_SAVED_QUERY: _NodeType.ValueType  # 13
    NODE_TYPE_SEMANTIC_MODEL: _NodeType.ValueType  # 14
    NODE_TYPE_FUNCTION: _NodeType.ValueType  # 15

class NodeType(_NodeType, metaclass=_NodeTypeEnumTypeWrapper):
    """Node type, also known as "resource type" in dbt core."""

NODE_TYPE_UNSPECIFIED: NodeType.ValueType  # 0
NODE_TYPE_MODEL: NodeType.ValueType  # 1
NODE_TYPE_SEED: NodeType.ValueType  # 2
NODE_TYPE_SNAPSHOT: NodeType.ValueType  # 11
NODE_TYPE_SOURCE: NodeType.ValueType  # 3
NODE_TYPE_TEST: NodeType.ValueType  # 4
NODE_TYPE_UNIT_TEST: NodeType.ValueType  # 5
NODE_TYPE_MACRO: NodeType.ValueType  # 6
NODE_TYPE_DOCS_MACRO: NodeType.ValueType  # 7
NODE_TYPE_ANALYSIS: NodeType.ValueType  # 8
NODE_TYPE_OPERATION: NodeType.ValueType  # 9
NODE_TYPE_EXPOSURE: NodeType.ValueType  # 10
NODE_TYPE_METRIC: NodeType.ValueType  # 12
NODE_TYPE_SAVED_QUERY: NodeType.ValueType  # 13
NODE_TYPE_SEMANTIC_MODEL: NodeType.ValueType  # 14
NODE_TYPE_FUNCTION: NodeType.ValueType  # 15
Global___NodeType: typing_extensions.TypeAlias = NodeType

class _NodeOutcome:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeOutcomeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeOutcome.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_OUTCOME_UNSPECIFIED: _NodeOutcome.ValueType  # 0
    """Default value. Should only be set on unfinished spans"""
    NODE_OUTCOME_SUCCESS: _NodeOutcome.ValueType  # 1
    """Successfully completed all operations in the phase.
    Some node types also store a type specific outcome for successful completion.
    """
    NODE_OUTCOME_ERROR: _NodeOutcome.ValueType  # 2
    """Failed with an aggregated error type (individual errors reported as separate events).
    If set, `node_error_type` with also be set to indicate the type of error.
    """
    NODE_OUTCOME_CANCELED: _NodeOutcome.ValueType  # 3
    """Operation was canceled (e.g. user-initiated cancellation).
    If set, `node_cancel_reason` will also be set to indicate the reason for the cancelation.
    """
    NODE_OUTCOME_SKIPPED: _NodeOutcome.ValueType  # 4
    """Skipped evaluation for a specific reason.
    If set, `node_skip_reason` will also be set to indicate the reason for the skip.
    """

class NodeOutcome(_NodeOutcome, metaclass=_NodeOutcomeEnumTypeWrapper):
    """Core outcome for any node evaluation result within any phase.
    Represents the aggregated result of all operations in the phase
    """

NODE_OUTCOME_UNSPECIFIED: NodeOutcome.ValueType  # 0
"""Default value. Should only be set on unfinished spans"""
NODE_OUTCOME_SUCCESS: NodeOutcome.ValueType  # 1
"""Successfully completed all operations in the phase.
Some node types also store a type specific outcome for successful completion.
"""
NODE_OUTCOME_ERROR: NodeOutcome.ValueType  # 2
"""Failed with an aggregated error type (individual errors reported as separate events).
If set, `node_error_type` with also be set to indicate the type of error.
"""
NODE_OUTCOME_CANCELED: NodeOutcome.ValueType  # 3
"""Operation was canceled (e.g. user-initiated cancellation).
If set, `node_cancel_reason` will also be set to indicate the reason for the cancelation.
"""
NODE_OUTCOME_SKIPPED: NodeOutcome.ValueType  # 4
"""Skipped evaluation for a specific reason.
If set, `node_skip_reason` will also be set to indicate the reason for the skip.
"""
Global___NodeOutcome: typing_extensions.TypeAlias = NodeOutcome

class _NodeErrorType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeErrorTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeErrorType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_ERROR_TYPE_INTERNAL: _NodeErrorType.ValueType  # 0
    """Internal dbt error (bug, panic, unexpected state) – not recoverable by retrying."""
    NODE_ERROR_TYPE_EXTERNAL: _NodeErrorType.ValueType  # 1
    """External system error (database down, network issue, etc.) – potentially recoverable by retrying."""
    NODE_ERROR_TYPE_USER: _NodeErrorType.ValueType  # 2
    """User code error (SQL syntax, compilation error, etc.) that must be fixed by the user."""

class NodeErrorType(_NodeErrorType, metaclass=_NodeErrorTypeEnumTypeWrapper):
    """Categorization of aggregated errors for debugging and retry logic.
    Errors form a hierarchy: if any internal error occurred, the aggregated result is INTERNAL.
    Otherwise if any external error occurred it is EXTERNAL. Otherwise it is USER.
    """

NODE_ERROR_TYPE_INTERNAL: NodeErrorType.ValueType  # 0
"""Internal dbt error (bug, panic, unexpected state) – not recoverable by retrying."""
NODE_ERROR_TYPE_EXTERNAL: NodeErrorType.ValueType  # 1
"""External system error (database down, network issue, etc.) – potentially recoverable by retrying."""
NODE_ERROR_TYPE_USER: NodeErrorType.ValueType  # 2
"""User code error (SQL syntax, compilation error, etc.) that must be fixed by the user."""
Global___NodeErrorType: typing_extensions.TypeAlias = NodeErrorType

class _NodeCancelReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeCancelReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeCancelReason.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_CANCEL_REASON_USER_CANCELLED: _NodeCancelReason.ValueType  # 0
    """User explicitly cancelled execution (e.g. ctrl-c)."""

class NodeCancelReason(_NodeCancelReason, metaclass=_NodeCancelReasonEnumTypeWrapper):
    """Reasons why a node evaluation was cabceled."""

NODE_CANCEL_REASON_USER_CANCELLED: NodeCancelReason.ValueType  # 0
"""User explicitly cancelled execution (e.g. ctrl-c)."""
Global___NodeCancelReason: typing_extensions.TypeAlias = NodeCancelReason

class _NodeSkipReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeSkipReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeSkipReason.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_SKIP_REASON_UNSPECIFIED: _NodeSkipReason.ValueType  # 0
    NODE_SKIP_REASON_UPSTREAM: _NodeSkipReason.ValueType  # 1
    """Skipped because an upstream dependency prevents this node from running (for any reason)."""
    NODE_SKIP_REASON_CACHED: _NodeSkipReason.ValueType  # 2
    """Reused from cache"""
    NODE_SKIP_REASON_PHASE_DISABLED: _NodeSkipReason.ValueType  # 3
    """Current evaluation phase disabled for this node by configuration / flags."""
    NODE_SKIP_REASON_NO_OP: _NodeSkipReason.ValueType  # 4
    """Operation had no effect (e.g. ephemeral models)."""
    NODE_SKIP_REASON_PHASE_SKIPPED: _NodeSkipReason.ValueType  # 5
    """Current evaluation phase skipped for this node due to previous phase outcome."""

class NodeSkipReason(_NodeSkipReason, metaclass=_NodeSkipReasonEnumTypeWrapper):
    """Reasons why a node may be skipped. Only applies to nodes selected for evaluation."""

NODE_SKIP_REASON_UNSPECIFIED: NodeSkipReason.ValueType  # 0
NODE_SKIP_REASON_UPSTREAM: NodeSkipReason.ValueType  # 1
"""Skipped because an upstream dependency prevents this node from running (for any reason)."""
NODE_SKIP_REASON_CACHED: NodeSkipReason.ValueType  # 2
"""Reused from cache"""
NODE_SKIP_REASON_PHASE_DISABLED: NodeSkipReason.ValueType  # 3
"""Current evaluation phase disabled for this node by configuration / flags."""
NODE_SKIP_REASON_NO_OP: NodeSkipReason.ValueType  # 4
"""Operation had no effect (e.g. ephemeral models)."""
NODE_SKIP_REASON_PHASE_SKIPPED: NodeSkipReason.ValueType  # 5
"""Current evaluation phase skipped for this node due to previous phase outcome."""
Global___NodeSkipReason: typing_extensions.TypeAlias = NodeSkipReason

class _NodeCacheReason:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeCacheReasonEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeCacheReason.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_CACHE_REASON_NO_CHANGES: _NodeCacheReason.ValueType  # 0
    """Reused from cache - no code or data changes detected."""
    NODE_CACHE_REASON_STILL_FRESH: _NodeCacheReason.ValueType  # 1
    """Reused from cache - changes detected but still within freshness window."""
    NODE_CACHE_REASON_UPDATE_CRITERIA_NOT_MET: _NodeCacheReason.ValueType  # 2
    """Reused from cache - changes detected but update criteria not met."""

class NodeCacheReason(_NodeCacheReason, metaclass=_NodeCacheReasonEnumTypeWrapper):
    """Cache reuse classification when node_skip_reason == NODE_SKIP_REASON_CACHED."""

NODE_CACHE_REASON_NO_CHANGES: NodeCacheReason.ValueType  # 0
"""Reused from cache - no code or data changes detected."""
NODE_CACHE_REASON_STILL_FRESH: NodeCacheReason.ValueType  # 1
"""Reused from cache - changes detected but still within freshness window."""
NODE_CACHE_REASON_UPDATE_CRITERIA_NOT_MET: NodeCacheReason.ValueType  # 2
"""Reused from cache - changes detected but update criteria not met."""
Global___NodeCacheReason: typing_extensions.TypeAlias = NodeCacheReason

class _NodeMaterialization:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _NodeMaterializationEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_NodeMaterialization.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NODE_MATERIALIZATION_UNKNOWN: _NodeMaterialization.ValueType  # 0
    NODE_MATERIALIZATION_SNAPSHOT: _NodeMaterialization.ValueType  # 1
    NODE_MATERIALIZATION_SEED: _NodeMaterialization.ValueType  # 2
    NODE_MATERIALIZATION_VIEW: _NodeMaterialization.ValueType  # 3
    NODE_MATERIALIZATION_TABLE: _NodeMaterialization.ValueType  # 4
    NODE_MATERIALIZATION_INCREMENTAL: _NodeMaterialization.ValueType  # 5
    NODE_MATERIALIZATION_MATERIALIZED_VIEW: _NodeMaterialization.ValueType  # 6
    NODE_MATERIALIZATION_EXTERNAL: _NodeMaterialization.ValueType  # 7
    NODE_MATERIALIZATION_TEST: _NodeMaterialization.ValueType  # 8
    NODE_MATERIALIZATION_EPHEMERAL: _NodeMaterialization.ValueType  # 9
    NODE_MATERIALIZATION_UNIT: _NodeMaterialization.ValueType  # 10
    NODE_MATERIALIZATION_ANALYSIS: _NodeMaterialization.ValueType  # 11
    NODE_MATERIALIZATION_STREAMING_TABLE: _NodeMaterialization.ValueType  # 12
    """ONLY FOR DATABRICKS"""
    NODE_MATERIALIZATION_DYNAMIC_TABLE: _NodeMaterialization.ValueType  # 13
    """ONLY FOR SNOWFLAKE"""
    NODE_MATERIALIZATION_FUNCTION: _NodeMaterialization.ValueType  # 14
    NODE_MATERIALIZATION_CUSTOM: _NodeMaterialization.ValueType  # 100

class NodeMaterialization(_NodeMaterialization, metaclass=_NodeMaterializationEnumTypeWrapper): ...

NODE_MATERIALIZATION_UNKNOWN: NodeMaterialization.ValueType  # 0
NODE_MATERIALIZATION_SNAPSHOT: NodeMaterialization.ValueType  # 1
NODE_MATERIALIZATION_SEED: NodeMaterialization.ValueType  # 2
NODE_MATERIALIZATION_VIEW: NodeMaterialization.ValueType  # 3
NODE_MATERIALIZATION_TABLE: NodeMaterialization.ValueType  # 4
NODE_MATERIALIZATION_INCREMENTAL: NodeMaterialization.ValueType  # 5
NODE_MATERIALIZATION_MATERIALIZED_VIEW: NodeMaterialization.ValueType  # 6
NODE_MATERIALIZATION_EXTERNAL: NodeMaterialization.ValueType  # 7
NODE_MATERIALIZATION_TEST: NodeMaterialization.ValueType  # 8
NODE_MATERIALIZATION_EPHEMERAL: NodeMaterialization.ValueType  # 9
NODE_MATERIALIZATION_UNIT: NodeMaterialization.ValueType  # 10
NODE_MATERIALIZATION_ANALYSIS: NodeMaterialization.ValueType  # 11
NODE_MATERIALIZATION_STREAMING_TABLE: NodeMaterialization.ValueType  # 12
"""ONLY FOR DATABRICKS"""
NODE_MATERIALIZATION_DYNAMIC_TABLE: NodeMaterialization.ValueType  # 13
"""ONLY FOR SNOWFLAKE"""
NODE_MATERIALIZATION_FUNCTION: NodeMaterialization.ValueType  # 14
NODE_MATERIALIZATION_CUSTOM: NodeMaterialization.ValueType  # 100
Global___NodeMaterialization: typing_extensions.TypeAlias = NodeMaterialization

class _TestOutcome:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TestOutcomeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TestOutcome.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TEST_OUTCOME_PASSED: _TestOutcome.ValueType  # 0
    """No failures found or below warning threshold."""
    TEST_OUTCOME_WARNED: _TestOutcome.ValueType  # 1
    """Failures found between warning and error thresholds."""
    TEST_OUTCOME_FAILED: _TestOutcome.ValueType  # 2
    """Failures found above error threshold."""

class TestOutcome(_TestOutcome, metaclass=_TestOutcomeEnumTypeWrapper):
    """Test-specific outcome details (only for TEST and UNITTEST node types)."""

TEST_OUTCOME_PASSED: TestOutcome.ValueType  # 0
"""No failures found or below warning threshold."""
TEST_OUTCOME_WARNED: TestOutcome.ValueType  # 1
"""Failures found between warning and error thresholds."""
TEST_OUTCOME_FAILED: TestOutcome.ValueType  # 2
"""Failures found above error threshold."""
Global___TestOutcome: typing_extensions.TypeAlias = TestOutcome

class _SourceFreshnessOutcome:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SourceFreshnessOutcomeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SourceFreshnessOutcome.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SOURCE_FRESHNESS_OUTCOME_OUTCOME_PASSED: _SourceFreshnessOutcome.ValueType  # 0
    """Freshness within acceptable (success) threshold."""
    SOURCE_FRESHNESS_OUTCOME_OUTCOME_WARNED: _SourceFreshnessOutcome.ValueType  # 1
    """Freshness exceeded warning threshold but below error threshold."""
    SOURCE_FRESHNESS_OUTCOME_OUTCOME_FAILED: _SourceFreshnessOutcome.ValueType  # 2
    """Freshness exceeded error threshold."""

class SourceFreshnessOutcome(_SourceFreshnessOutcome, metaclass=_SourceFreshnessOutcomeEnumTypeWrapper):
    """Freshness-specific outcome details (only for SOURCE nodes with freshness checks)."""

SOURCE_FRESHNESS_OUTCOME_OUTCOME_PASSED: SourceFreshnessOutcome.ValueType  # 0
"""Freshness within acceptable (success) threshold."""
SOURCE_FRESHNESS_OUTCOME_OUTCOME_WARNED: SourceFreshnessOutcome.ValueType  # 1
"""Freshness exceeded warning threshold but below error threshold."""
SOURCE_FRESHNESS_OUTCOME_OUTCOME_FAILED: SourceFreshnessOutcome.ValueType  # 2
"""Freshness exceeded error threshold."""
Global___SourceFreshnessOutcome: typing_extensions.TypeAlias = SourceFreshnessOutcome

@typing.final
class TestEvaluationDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEST_OUTCOME_FIELD_NUMBER: builtins.int
    FAILING_ROWS_FIELD_NUMBER: builtins.int
    DIFF_TABLE_FIELD_NUMBER: builtins.int
    test_outcome: Global___TestOutcome.ValueType
    failing_rows: builtins.int
    """Number of failing rows for this test."""
    diff_table: builtins.str
    """Pretty printed table diff if available."""
    def __init__(
        self,
        *,
        test_outcome: Global___TestOutcome.ValueType = ...,
        failing_rows: builtins.int = ...,
        diff_table: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_diff_table", b"_diff_table", "diff_table", b"diff_table"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_diff_table", b"_diff_table", "diff_table", b"diff_table", "failing_rows", b"failing_rows", "test_outcome", b"test_outcome"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["_diff_table", b"_diff_table"]) -> typing.Literal["diff_table"] | None: ...

Global___TestEvaluationDetail: typing_extensions.TypeAlias = TestEvaluationDetail

@typing.final
class SourceFreshnessDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_FRESHNESS_OUTCOME_FIELD_NUMBER: builtins.int
    node_freshness_outcome: Global___SourceFreshnessOutcome.ValueType
    def __init__(
        self,
        *,
        node_freshness_outcome: Global___SourceFreshnessOutcome.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_freshness_outcome", b"node_freshness_outcome"]) -> None: ...

Global___SourceFreshnessDetail: typing_extensions.TypeAlias = SourceFreshnessDetail

@typing.final
class NodeCacheDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_CACHE_REASON_FIELD_NUMBER: builtins.int
    node_cache_reason: Global___NodeCacheReason.ValueType
    def __init__(
        self,
        *,
        node_cache_reason: Global___NodeCacheReason.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_cache_reason", b"node_cache_reason"]) -> None: ...

Global___NodeCacheDetail: typing_extensions.TypeAlias = NodeCacheDetail

@typing.final
class NodeSkipUpstreamDetail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UPSTREAM_UNIQUE_ID_FIELD_NUMBER: builtins.int
    upstream_unique_id: builtins.str
    """unique_id of the upstream node that caused this node to be skipped."""
    def __init__(
        self,
        *,
        upstream_unique_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["upstream_unique_id", b"upstream_unique_id"]) -> None: ...

Global___NodeSkipUpstreamDetail: typing_extensions.TypeAlias = NodeSkipUpstreamDetail

@typing.final
class NodeEvaluated(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIQUE_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    IDENTIFIER_FIELD_NUMBER: builtins.int
    MATERIALIZATION_FIELD_NUMBER: builtins.int
    CUSTOM_MATERIALIZATION_FIELD_NUMBER: builtins.int
    NODE_TYPE_FIELD_NUMBER: builtins.int
    NODE_OUTCOME_FIELD_NUMBER: builtins.int
    PHASE_FIELD_NUMBER: builtins.int
    NODE_ERROR_TYPE_FIELD_NUMBER: builtins.int
    NODE_CANCEL_REASON_FIELD_NUMBER: builtins.int
    NODE_SKIP_REASON_FIELD_NUMBER: builtins.int
    NODE_CACHE_DETAIL_FIELD_NUMBER: builtins.int
    NODE_TEST_DETAIL_FIELD_NUMBER: builtins.int
    NODE_FRESHNESS_OUTCOME_FIELD_NUMBER: builtins.int
    NODE_SKIP_UPSTREAM_DETAIL_FIELD_NUMBER: builtins.int
    DBT_CORE_EVENT_CODE_FIELD_NUMBER: builtins.int
    unique_id: builtins.str
    """unique_id is the globally unique identifier for this node."""
    name: builtins.str
    """Node name."""
    database: builtins.str
    """Database where this node will be created if applicable."""
    schema: builtins.str
    """Schema where this node will be created if applicable."""
    identifier: builtins.str
    """Name of the relation (table, view, etc.) that will be created for this node if applicable."""
    materialization: Global___NodeMaterialization.ValueType
    """How this node is materialized in the data warehouse."""
    custom_materialization: builtins.str
    """If materialization == NODE_MATERIALIZATION_CUSTOM, this field contains the custom materialization name."""
    node_type: Global___NodeType.ValueType
    """Type of node being evaluated. Known as `resource_type` in dbt core."""
    node_outcome: Global___NodeOutcome.ValueType
    """Core outcome for this evaluation."""
    phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType
    """Execution phase during which this node was evaluated."""
    node_error_type: Global___NodeErrorType.ValueType
    """Granular reasons for unsuccessful outcomes (error, canceled, skipped).

    Categorization of aggregated errors for debugging and retry logic.
    Present when node_outcome == NODE_OUTCOME_ERROR.
    """
    node_cancel_reason: Global___NodeCancelReason.ValueType
    """Cancellation reason.
    Present when node_outcome == NODE_OUTCOME_CANCELED.
    """
    node_skip_reason: Global___NodeSkipReason.ValueType
    """Detailed reason for skipping this node.
    Present when node_outcome == NODE_OUTCOME_SKIPPED.
    """
    dbt_core_event_code: builtins.str
    """Optional legacy dbt core event code (e.g. "Q018") if this event has a strict mapping to a dbt core event."""
    @property
    def node_cache_detail(self) -> Global___NodeCacheDetail:
        """Detailed reason why cache was used.
        Present when node_skip_reason == NODE_SKIP_REASON_CACHED.
        """

    @property
    def node_test_detail(self) -> Global___TestEvaluationDetail:
        """Test specific outcome details.
        Present for test / unit test node types when node_outcome == NODE_OUTCOME_SUCCESS.
        """

    @property
    def node_freshness_outcome(self) -> Global___SourceFreshnessDetail:
        """Source freshness specific outcome details.
        Present for source nodes with freshness checks when node_outcome == NODE_OUTCOME_SUCCESS.
        """

    @property
    def node_skip_upstream_detail(self) -> Global___NodeSkipUpstreamDetail:
        """Upstream node that caused this node to be skipped.
        Present when node_skip_reason == NODE_SKIP_REASON_UPSTREAM.
        """

    def __init__(
        self,
        *,
        unique_id: builtins.str = ...,
        name: builtins.str = ...,
        database: builtins.str | None = ...,
        schema: builtins.str | None = ...,
        identifier: builtins.str | None = ...,
        materialization: Global___NodeMaterialization.ValueType | None = ...,
        custom_materialization: builtins.str | None = ...,
        node_type: Global___NodeType.ValueType = ...,
        node_outcome: Global___NodeOutcome.ValueType = ...,
        phase: dbtlabs.proto.public.v1.events.fusion.phase.phase_pb2.ExecutionPhase.ValueType = ...,
        node_error_type: Global___NodeErrorType.ValueType | None = ...,
        node_cancel_reason: Global___NodeCancelReason.ValueType | None = ...,
        node_skip_reason: Global___NodeSkipReason.ValueType | None = ...,
        node_cache_detail: Global___NodeCacheDetail | None = ...,
        node_test_detail: Global___TestEvaluationDetail | None = ...,
        node_freshness_outcome: Global___SourceFreshnessDetail | None = ...,
        node_skip_upstream_detail: Global___NodeSkipUpstreamDetail | None = ...,
        dbt_core_event_code: builtins.str | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["_custom_materialization", b"_custom_materialization", "_database", b"_database", "_dbt_core_event_code", b"_dbt_core_event_code", "_identifier", b"_identifier", "_materialization", b"_materialization", "_node_cancel_reason", b"_node_cancel_reason", "_node_error_type", b"_node_error_type", "_node_skip_reason", b"_node_skip_reason", "_schema", b"_schema", "custom_materialization", b"custom_materialization", "database", b"database", "dbt_core_event_code", b"dbt_core_event_code", "identifier", b"identifier", "materialization", b"materialization", "node_cache_detail", b"node_cache_detail", "node_cancel_reason", b"node_cancel_reason", "node_error_type", b"node_error_type", "node_freshness_outcome", b"node_freshness_outcome", "node_outcome_detail", b"node_outcome_detail", "node_skip_reason", b"node_skip_reason", "node_skip_upstream_detail", b"node_skip_upstream_detail", "node_test_detail", b"node_test_detail", "schema", b"schema"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["_custom_materialization", b"_custom_materialization", "_database", b"_database", "_dbt_core_event_code", b"_dbt_core_event_code", "_identifier", b"_identifier", "_materialization", b"_materialization", "_node_cancel_reason", b"_node_cancel_reason", "_node_error_type", b"_node_error_type", "_node_skip_reason", b"_node_skip_reason", "_schema", b"_schema", "custom_materialization", b"custom_materialization", "database", b"database", "dbt_core_event_code", b"dbt_core_event_code", "identifier", b"identifier", "materialization", b"materialization", "name", b"name", "node_cache_detail", b"node_cache_detail", "node_cancel_reason", b"node_cancel_reason", "node_error_type", b"node_error_type", "node_freshness_outcome", b"node_freshness_outcome", "node_outcome", b"node_outcome", "node_outcome_detail", b"node_outcome_detail", "node_skip_reason", b"node_skip_reason", "node_skip_upstream_detail", b"node_skip_upstream_detail", "node_test_detail", b"node_test_detail", "node_type", b"node_type", "phase", b"phase", "schema", b"schema", "unique_id", b"unique_id"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_custom_materialization", b"_custom_materialization"]) -> typing.Literal["custom_materialization"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_database", b"_database"]) -> typing.Literal["database"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_dbt_core_event_code", b"_dbt_core_event_code"]) -> typing.Literal["dbt_core_event_code"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_identifier", b"_identifier"]) -> typing.Literal["identifier"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_materialization", b"_materialization"]) -> typing.Literal["materialization"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_node_cancel_reason", b"_node_cancel_reason"]) -> typing.Literal["node_cancel_reason"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_node_error_type", b"_node_error_type"]) -> typing.Literal["node_error_type"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_node_skip_reason", b"_node_skip_reason"]) -> typing.Literal["node_skip_reason"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["_schema", b"_schema"]) -> typing.Literal["schema"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["node_outcome_detail", b"node_outcome_detail"]) -> typing.Literal["node_cache_detail", "node_test_detail", "node_freshness_outcome", "node_skip_upstream_detail"] | None: ...

Global___NodeEvaluated: typing_extensions.TypeAlias = NodeEvaluated



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dbtlabs/proto/public/v1/fields/common_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1dbtlabs/proto/public/v1/fields/common_types.proto\x12\x1dv1.public.fields.common_types\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa3\x02\n\tEventInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12\r\n\x05level\x18\x04 \x01(\t\x12\x15\n\rinvocation_id\x18\x05 \x01(\t\x12\x0b\n\x03pid\x18\x06 \x01(\x05\x12\x0e\n\x06thread\x18\x07 \x01(\t\x12&\n\x02ts\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x42\n\x05\x65xtra\x18\t \x03(\x0b\x32\x33.v1.public.fields.common_types.EventInfo.ExtraEntry\x12\x10\n\x08\x63\x61tegory\x18\n \x01(\t\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x0eGenericMessage\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\"d\n\x13\x42\x65haviorChangeEvent\x12\x11\n\tflag_name\x18\x01 \x01(\t\x12\x13\n\x0b\x66lag_source\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x64ocs_url\x18\x04 \x01(\t\"\x92\x01\n\x16\x42\x65haviorChangeEventMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.common_types.BehaviorChangeEvent\"1\n\x11RetryExternalCall\x12\x0f\n\x07\x61ttempt\x18\x01 \x01(\x05\x12\x0b\n\x03max\x18\x02 \x01(\x05\"\x8e\x01\n\x14RetryExternalCallMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.common_types.RetryExternalCall\"#\n\x14RecordRetryException\x12\x0b\n\x03\x65xc\x18\x01 \x01(\t\"\x94\x01\n\x17RecordRetryExceptionMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x41\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x33.v1.public.fields.common_types.RecordRetryException\"@\n\x13SystemCouldNotWrite\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\x12\x0b\n\x03\x65xc\x18\x03 \x01(\t\"\x92\x01\n\x16SystemCouldNotWriteMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12@\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x32.v1.public.fields.common_types.SystemCouldNotWrite\"!\n\x12SystemExecutingCmd\x12\x0b\n\x03\x63md\x18\x01 \x03(\t\"\x90\x01\n\x15SystemExecutingCmdMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12?\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x31.v1.public.fields.common_types.SystemExecutingCmd\"\x1c\n\x0cSystemStdOut\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"\x84\x01\n\x0fSystemStdOutMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.common_types.SystemStdOut\"\x1c\n\x0cSystemStdErr\x12\x0c\n\x04\x62msg\x18\x01 \x01(\t\"\x84\x01\n\x0fSystemStdErrMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x39\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32+.v1.public.fields.common_types.SystemStdErr\",\n\x16SystemReportReturnCode\x12\x12\n\nreturncode\x18\x01 \x01(\x05\"\x98\x01\n\x19SystemReportReturnCodeMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x43\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x35.v1.public.fields.common_types.SystemReportReturnCode\"\x19\n\nFormatting\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x80\x01\n\rFormattingMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.common_types.Formatting\"\x13\n\x04Note\x12\x0b\n\x03msg\x18\x01 \x01(\t\"t\n\x07NoteMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x31\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32#.v1.public.fields.common_types.Note\"\x19\n\nPrintEvent\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x80\x01\n\rPrintEventMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12\x37\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32).v1.public.fields.common_types.PrintEvent\" \n\x11RecordReplayIssue\x12\x0b\n\x03msg\x18\x01 \x01(\t\"\x8e\x01\n\x14RecordReplayIssueMsg\x12\x36\n\x04info\x18\x01 \x01(\x0b\x32(.v1.public.fields.common_types.EventInfo\x12>\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x30.v1.public.fields.common_types.RecordReplayIssueB@Z>github.com/dbt-labs/proto-golang/v1/public/fields/common_typesb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'dbtlabs.proto.public.v1.fields.common_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z>github.com/dbt-labs/proto-golang/v1/public/fields/common_types'
  _globals['_EVENTINFO_EXTRAENTRY']._loaded_options = None
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_options = b'8\001'
  _globals['_EVENTINFO']._serialized_start=118
  _globals['_EVENTINFO']._serialized_end=409
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_start=365
  _globals['_EVENTINFO_EXTRAENTRY']._serialized_end=409
  _globals['_GENERICMESSAGE']._serialized_start=411
  _globals['_GENERICMESSAGE']._serialized_end=483
  _globals['_BEHAVIORCHANGEEVENT']._serialized_start=485
  _globals['_BEHAVIORCHANGEEVENT']._serialized_end=585
  _globals['_BEHAVIORCHANGEEVENTMSG']._serialized_start=588
  _globals['_BEHAVIORCHANGEEVENTMSG']._serialized_end=734
  _globals['_RETRYEXTERNALCALL']._serialized_start=736
  _globals['_RETRYEXTERNALCALL']._serialized_end=785
  _globals['_RETRYEXTERNALCALLMSG']._serialized_start=788
  _globals['_RETRYEXTERNALCALLMSG']._serialized_end=930
  _globals['_RECORDRETRYEXCEPTION']._serialized_start=932
  _globals['_RECORDRETRYEXCEPTION']._serialized_end=967
  _globals['_RECORDRETRYEXCEPTIONMSG']._serialized_start=970
  _globals['_RECORDRETRYEXCEPTIONMSG']._serialized_end=1118
  _globals['_SYSTEMCOULDNOTWRITE']._serialized_start=1120
  _globals['_SYSTEMCOULDNOTWRITE']._serialized_end=1184
  _globals['_SYSTEMCOULDNOTWRITEMSG']._serialized_start=1187
  _globals['_SYSTEMCOULDNOTWRITEMSG']._serialized_end=1333
  _globals['_SYSTEMEXECUTINGCMD']._serialized_start=1335
  _globals['_SYSTEMEXECUTINGCMD']._serialized_end=1368
  _globals['_SYSTEMEXECUTINGCMDMSG']._serialized_start=1371
  _globals['_SYSTEMEXECUTINGCMDMSG']._serialized_end=1515
  _globals['_SYSTEMSTDOUT']._serialized_start=1517
  _globals['_SYSTEMSTDOUT']._serialized_end=1545
  _globals['_SYSTEMSTDOUTMSG']._serialized_start=1548
  _globals['_SYSTEMSTDOUTMSG']._serialized_end=1680
  _globals['_SYSTEMSTDERR']._serialized_start=1682
  _globals['_SYSTEMSTDERR']._serialized_end=1710
  _globals['_SYSTEMSTDERRMSG']._serialized_start=1713
  _globals['_SYSTEMSTDERRMSG']._serialized_end=1845
  _globals['_SYSTEMREPORTRETURNCODE']._serialized_start=1847
  _globals['_SYSTEMREPORTRETURNCODE']._serialized_end=1891
  _globals['_SYSTEMREPORTRETURNCODEMSG']._serialized_start=1894
  _globals['_SYSTEMREPORTRETURNCODEMSG']._serialized_end=2046
  _globals['_FORMATTING']._serialized_start=2048
  _globals['_FORMATTING']._serialized_end=2073
  _globals['_FORMATTINGMSG']._serialized_start=2076
  _globals['_FORMATTINGMSG']._serialized_end=2204
  _globals['_NOTE']._serialized_start=2206
  _globals['_NOTE']._serialized_end=2225
  _globals['_NOTEMSG']._serialized_start=2227
  _globals['_NOTEMSG']._serialized_end=2343
  _globals['_PRINTEVENT']._serialized_start=2345
  _globals['_PRINTEVENT']._serialized_end=2370
  _globals['_PRINTEVENTMSG']._serialized_start=2373
  _globals['_PRINTEVENTMSG']._serialized_end=2501
  _globals['_RECORDREPLAYISSUE']._serialized_start=2503
  _globals['_RECORDREPLAYISSUE']._serialized_end=2535
  _globals['_RECORDREPLAYISSUEMSG']._serialized_start=2538
  _globals['_RECORDREPLAYISSUEMSG']._serialized_end=2680
# @@protoc_insertion_point(module_scope)
